#include <iostream>
#include <vector>
#include <queue>
#include <cassert>
using std::cout; using std::endl; using std::cerr; using std::cin;

int N, M;
const int MAX_N = 3e5 + 10;

/*
// Global
struct Event {
	int reserv;
	int nei;
	double atCapacity;
};
std::priority_queue<Event> events;
*/

// за даден интервал [Wa Wb], има битмаск в кои резервоари отива водата
struct WorldState {
	double fromW;
	double toW;
	std::vector<int> connected;
	std::vector<double> filledCapacity;
};
std::vector<WorldState> precompute;


// Per reserv
struct Event {
	int from;
	int nei;
	long long atCapacity;
	char type;
	bool operator < (const Event &other) const {
		if(atCapacity == other.atCapacity) return type == 'a';
		return atCapacity > other.atCapacity;
	}
	void print() const {
		cout << '(' << type << ')' << "event from " << from << " to " << nei << " at " << atCapacity << endl;
	}
};

std::priority_queue<Event> events[MAX_N];
std::vector<double> filledCapacity;
//std::vector<std::pair<int, double>> graph[MAX_N];
double currW = 0;

constexpr bool eq(long long a, double b) {
	return std::abs(double(a) - b) < 0.00001;
}

#define DISCARDABLE (top.atCapacity < filledCapacity[idx] or (top.type == 'a' and eq(top.atCapacity, filledCapacity[idx])))
Event getEvent(int idx) {
	while(events[idx].size()) {
		Event top = events[idx].top();
		events[idx].pop();
		if(DISCARDABLE) continue;
		return top;
	}
}
Event peekEvent(int idx) {
	while(events[idx].size()) {
		Event top = events[idx].top();
		if(DISCARDABLE) {
			events[idx].pop();
			continue;
		}
		return top;
	}
}

std::vector<int> sim(std::vector<int> connected, int depth) {
#define D cout << std::string(depth, '-')
	while(true) {
		/*
		D << "starting sim with cW=" << currW << endl;
		assert(connected.size() > 0);

		D << "connected=";
		for(auto x : connected) cout << x << ',';
		cout << endl;

		D << "filled=";
		for(auto x : connected) cout << x << ')' << filledCapacity[x] << '\t';
		cout << endl;
		*/

		Event minEvent = {-1, -1, (1ll<<61), 'x'};
		for(auto x : connected) {
			beginPeek:
			const auto E = peekEvent(x);
			for(auto y : connected) {
				if(E.nei == y) {
					events[x].pop();
					goto beginPeek;
				}
			}
			//D; cout << "peek=>"; E.print();
			// actutually is my operator < is >
			if(minEvent < E) minEvent = E;
		}

		minEvent = getEvent(minEvent.from);
		//D << "taken=>"; minEvent.print();

		const double addPerResrv = minEvent.atCapacity - filledCapacity[minEvent.from];
		const double W = addPerResrv * connected.size();

		//precompute.push_back({currW, currW + W, connected, filledCapacity});

		for(auto x : connected) filledCapacity[x] += addPerResrv;
		currW += W;
		//D << "simulated to " << currW << endl;

		if(minEvent.type == 'a') {
			std::vector<int> nc;
			nc.push_back(minEvent.nei);

			Event newEvent = {minEvent.nei, minEvent.from, minEvent.atCapacity, 'e'};
			events[minEvent.nei].push(newEvent);
			//D << "crafted=>"; newEvent.print();

			auto retConn = sim(nc, depth + 1);

			for(auto x : retConn) connected.push_back(x);
		} else {
			return connected;
		}
	}
}

void init(int _N, int _M, int a[], int b[], long long c[]) {
	N = _N;
	M = _M;

	for(int i = 0;i < M;i ++) {
		//graph[a[i]].push_back({b[i], c[i]});
		//graph[b[i]].push_back({a[i], c[i]});

		events[a[i]].push({a[i], b[i], c[i], 'a'});
		events[b[i]].push({b[i], a[i], c[i], 'a'});
		//cout << "add " << a[i] << ' ' << b[i] << ' ' << c[i] << endl;
	}

	for(int i = 1;i <= N;i ++) events[i].push({i, -1, (1ll<<60), 'x'});
	filledCapacity.resize(N+1);

	// изсимулирай 1e12 вода
	std::vector<int> connected = {1};
	while(currW < 1e13) {
		connected = sim(connected, 1);
	}

	/*
	for(auto &ws : precompute) {
		cout << "==================\n";
		cout << ws.fromW << "<->" << ws.toW << ":\n";
		for(auto c : ws.connected) cout << c << ',';
		cout << '\n';
		for(int i = 1;i <= N;i ++) cout << i << ')' << ws.filledCapacity[i] << '\t';
		cout << endl;
	}
	*/
}

double query(long long W, int print_target) {
	// двуично търсене из precompute, без симулации
	return 0.0;

	//cout << "query " << W << ' ' << print_target << endl;
	std::vector<int> conn;
	std::vector<double> F;
	for(auto &ws : precompute) {
		if(ws.fromW <= W and W < ws.toW) {
			W -= ws.fromW;
			conn = ws.connected;
			F = ws.filledCapacity;
			break;
		}
	}

	const double add = double(W) / conn.size();
	for(auto x : conn) F[x] += add;

	return F[print_target];
}
