#include <bits/stdc++.h>

#pragma GCC optimize "-O3"

#define endl '\n'
#define trace(x) cerr << #x << " = " << x << endl

using namespace std;

const int INF = 1 << 30;

class Point {
public:
    int x;
    int y;

    Point(int x = 0, int y = 0) {
        this->x = x;
        this->y = y;
    }
};

class Rectangle {
public:
    Point leftmost;
    Point rightmost;

    Rectangle(Point leftmost, Point rightmost) {
        this->leftmost = leftmost;
        this->rightmost = rightmost;
    }
};

class Square {
public:
    Point leftmost;
    int side_length;

    Square(Point leftmost, int side_length) {
        this->leftmost = leftmost;
        this->side_length = side_length;
    }

    bool belongs(Point p) {
        return (p.x >= this->leftmost.x && p.y >= this->leftmost.y
                && p.x <= this->leftmost.x + this->side_length
                && p.y <= this->leftmost.y + this->side_length);
    }

    bool belongs(Rectangle r) {
        return (this->belongs(r.leftmost) && this->belongs(r.rightmost));
    }
};

void set_io() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);
}

int n, m;
vector<Square> squares;
vector<int> Xs, Ys;

void read() {
    cin >> n;

    int x;
    cin >> x;

    for (int i = 0; i < n; i++) {
        int length;
        cin >> length;

        squares.emplace_back(Point(x - length, -length), length);

        Xs.emplace_back(x - length);
        Xs.emplace_back(x + length);

        Ys.emplace_back(-length);
        Ys.emplace_back(length);
    }

    cin >> m;

    cin >> x;

    for (int i = 0; i < m; i++) {
        int length;
        cin >> length;

        squares.emplace_back(Point(x - length, -length), length);

        Xs.emplace_back(x - length);
        Xs.emplace_back(x + length);

        Ys.emplace_back(-length);
        Ys.emplace_back(length);
    }
}

int get_square_id(Rectangle r) {
    for (int i = 0; i < n + m; i++) {
        if (squares[i].belongs(r)) {
            return i;
        }
    }

    return -1;
}

vector<pair<Rectangle, int>> parts;
vector<vector<int>> adj_list;

bool are_adjecent(Rectangle a, Rectangle b) {
    vector<Point> a_points;
    a_points.emplace_back(a.leftmost);
    a_points.emplace_back(a.rightmost);
    a_points.emplace_back(a.rightmost.x, a.leftmost.y);
    a_points.emplace_back(a.leftmost.x, a.rightmost.y);

    vector<Point> b_points;
    b_points.emplace_back(b.leftmost);
    b_points.emplace_back(b.rightmost);
    b_points.emplace_back(b.rightmost.x, b.leftmost.y);
    b_points.emplace_back(b.leftmost.x, b.rightmost.y);

    for (int i = 0; i < 4; i++) {
        for (int j = 0; j < 4; j++) {
            if (a_points[i].x == b_points[j].x && a_points[i].y == b_points[j].y) {
                return true;
            }
        }
    }

    return false;
}

vector<bool> seen;

void dfs(int node) {
    seen[node] = true;

    for (int adj_node : adj_list[node]) {
        if (!seen[adj_node]) {
            dfs(adj_node);
        }
    }
}

int main() {
    set_io();

    read();

    sort(Xs.begin(), Xs.end());
    sort(Ys.begin(), Ys.end());

    for (int i = 0; i < (int)Xs.size() - 1; i++) {
        for (int j = 0; j < (int)Ys.size() - 1; j++) {
            Rectangle part({Xs[i], Ys[j]}, {Xs[i + 1], Ys[j + 1]});
            int square_id = get_square_id(part);

            if (square_id != -1) {
                parts.emplace_back(part, square_id);
            }
        }
    }

    adj_list.resize(parts.size());

    for (int i = 0; i < (int)parts.size(); i++) {
        for (int j = i + 1; j < (int)parts.size(); j++) {
            if (parts[i].second != parts[j].second) {
                continue;
            }

            if (are_adjecent(parts[i].first, parts[j].first)) {
                adj_list[i].emplace_back(j);
                adj_list[j].emplace_back(i);
            }
        }
    }

    int cnt = 0;

    seen.resize(parts.size(), false);

    for (int i = 0; i < (int)parts.size(); i++) {
        if (!seen[i]) {
            cnt++;
            dfs(i);
        }
    }

    cout << cnt << endl;

    return EXIT_SUCCESS;
}
